# Citation

If you find *nuance* useful for your research, cite [Garcia et. al 2024](https://ui.adsabs.harvard.edu/abs/2024AJ....167..284G). The BibTeX entry for the paper is:

```
@ARTICLE{2024AJ....167..284G,
       author = {{Garcia}, Lionel J. and {Foreman-Mackey}, Daniel and {Murray}, Catriona A. and {Aigrain}, Suzanne and {Feliz}, Dax L. and {Pozuelos}, Francisco J.},
        title = "{nuance: Efficient Detection of Planets Transiting Active Stars}",
      journal = {\aj},
     keywords = {Exoplanet detection methods, Stellar activity, Time series analysis, Gaussian Processes regression, Computational methods, GPU computing, 489, 1580, 1916, 1930, 1965, 1969, Astrophysics - Earth and Planetary Astrophysics, Astrophysics - Instrumentation and Methods for Astrophysics},
         year = 2024,
        month = jun,
       volume = {167},
       number = {6},
          eid = {284},
        pages = {284},
          doi = {10.3847/1538-3881/ad3cd6},
archivePrefix = {arXiv},
       eprint = {2402.06835},
 primaryClass = {astro-ph.EP},
       adsurl = {https://ui.adsabs.harvard.edu/abs/2024AJ....167..284G},
      adsnote = {Provided by the SAO/NASA Astrophysics Data System}
}
```